@@ -20,20 +20,25 @@ func TestCheckForFeatureGates(t *testing.T) {
 			name:        "default",
 			configValue: configv1.Default,
 			expectedResult: map[string]bool{
-				"ExperimentalCriticalPodAnnotation": true,
-				"RotateKubeletServerCertificate":    true,
-				"SupportPodPidsLimit":               true,
-				"LocalStorageCapacityIsolation":     false,
+				// as copied from vendor/github.com/openshift/api/config/v1/types_feature.go
+				"RotateKubeletServerCertificate": true,
+				"SupportPodPidsLimit":            true,
+				"NodeDisruptionExclusion":        true,
+				"ServiceNodeExclusion":           true,
+				"LegacyNodeRoleBehavior":         false,
+				"SCTPSupport":                    true,
 			},
 		},
 		{
 			name:        "techpreview",
 			configValue: configv1.TechPreviewNoUpgrade,
 			expectedResult: map[string]bool{
-				"ExperimentalCriticalPodAnnotation": true,
-				"RotateKubeletServerCertificate":    true,
-				"SupportPodPidsLimit":               true,
-				"LocalStorageCapacityIsolation":     false,
+				// as copied from vendor/github.com/openshift/api/config/v1/types_feature.go
+				"RotateKubeletServerCertificate": true,
+				"SupportPodPidsLimit":            true,
+				"NodeDisruptionExclusion":        true,
+				"ServiceNodeExclusion":           true,
+				"LegacyNodeRoleBehavior":         false,
 			},
 		},
 	}
